pub struct ConnAck {
pub flags: u8,
pub extra: i16,
pub version: i8,
}Expand description
Data received right after initializing the connection
ConnAck is serialized sequentially
Fields
flags: u8The Flag 0x01 for TLS and 0x02 for Deflate Compression
extra: i16Some extra protocol version specific data So far unused
version: i8The version of the protocol 0x00000001 for the legacy protocol 0x00000002 for the datastream protocol
Only the datastream protocol is supported by this crate